==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_co.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=co
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'solu à l’artìculi futuri (nisuna mudìfica à a basa attuale).',
	'bouton_radio_articles_tous' => 'à tutti l’artìculi quant’elli sò.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'à tutti l’artìculi salvu quelli per chì hè disattivatu u foru.',
	'bouton_radio_enregistrement_obligatoire' => 'Arregistramenu ubbligatoriu (l’utilizatori devenu abbunà si rinsignendu u so indirizzu e-mail prima di pudè mandà cuntributi).',
	'bouton_radio_moderation_priori' => 'Muderazione in antìcipu (i cuntributi ùn sò pubblicati chè dopu accunsentu da l’amministratori).', # MODIF
	'bouton_radio_modere_abonnement' => 'Solu cù abbunamentu',
	'bouton_radio_modere_posteriori' => 'Muderazione dopu', # MODIF
	'bouton_radio_modere_priori' => 'muderazione in antìcipu', # MODIF
	'bouton_radio_publication_immediate' => 'Pubblicazione à l’istante di i messagi
(e cuntribuzioni sò pubblicate subbitu dopu mandate, l’amministradori i ponu sguassà dopu).',

	// D
	'documents_interdits_forum' => 'Ducumenti interdetti in u foru',

	// F
	'form_pet_message_commentaire' => 'Qualchì messagiu o cummentu ?',
	'forum' => 'Foru',
	'forum_acces_refuse' => 'Ùn avete più accessu à sti fori.',
	'forum_attention_dix_caracteres' => '<b>Attenti !</b> U vostru messagiu deve cuntene à u mìnimu dece caràtteri.',
	'forum_attention_trois_caracteres' => '<b>Attenti !</b> U vostru tìtulu deve cuntene à u mìnimu trè caràtteri.',
	'forum_attention_trop_caracteres' => '<b>Attention !</b> U vostru messagiu hè troppu longu (@compte@ caràtteri) : pè pudè esse arregistratu, 
	ùn deve superà @max@ caràtteri.', # MODIF
	'forum_avez_selectionne' => 'Avete sceltu :',
	'forum_cliquer_retour' => 'Cliccate <a href=\'@retour_forum@\'>quì</a> per cuntinuà.',
	'forum_forum' => 'foru',
	'forum_info_modere' => 'Stu foru hè muderatu prima : u vostru cuntributu cumpariscerà solu dopu esse statu accunsentutu da un amministratore di u situ.', # MODIF
	'forum_lien_hyper' => '<b>Lea ipertestu</b> (micca ubbligatoria)', # MODIF
	'forum_message_definitif' => 'Messagiu definitivu : mandà à u situ',
	'forum_message_trop_long' => 'U vostru messagiu hè troppu longu. A taglia màsima hè di 20 000 caràtteri.', # MODIF
	'forum_ne_repondez_pas' => 'Ùn rispundite micca à stu mail ma piuttostu nant’à u foru, à st’indirizzu :', # MODIF
	'forum_page_url' => '(Sì u vostru messagiu siriferisce à un artìculu pubblicatu nant’à u web, o à una pàgina 
	chì furnisce di più infurmazioni, pudete puru rinsignà custì u tìtulu di a pàgina cù u so indirizzu.)',
	'forum_poste_par' => 'Messagiu postu@parauteur@ in coda di l’artìculu « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Quale site ?</b> (micca ubbligatoriu)', # MODIF
	'forum_texte' => 'Testu di u vostru messagiu :', # MODIF
	'forum_titre' => 'Tìtulu',
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Cunvalidà sta scelta',
	'forum_voir_avant' => 'Vede u messagiu prima di pustà lu', # MODIF
	'forum_votre_email' => 'U vostru indirizzu email :', # MODIF
	'forum_votre_nom' => 'U vostru nome (o pseudo) :', # MODIF
	'forum_vous_enregistrer' => 'Per participà à stu foru, duvite esse digià arregistratu. 
		Rinsignate puru quì sottu u còdice persunale chì v’hè statu furnitu.
		Sè vo ùn site ancu à arregistrà, vi tocca à',
	'forum_vous_inscrire' => 'iscrive vi.',

	// I
	'icone_poster_message' => 'Mandà un messagiu',
	'icone_suivi_forum' => 'Guardia di u foru pùbblicu : @nb_forums@ cuntributi',
	'icone_suivi_forums' => 'Seguità/gestisce i fori',
	'icone_supprimer_message' => 'Sguassà stu messagiu',
	'icone_valider_message' => 'Cunvalidà stu messagiu',
	'info_activer_forum_public' => '<i>Per attivà i fori pùbblichi, sceglite puru u tippu 
	di muderazione predefinitu :</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Serà appiecata sta scelta di muderazione :',
	'info_config_forums_prive' => 'In u spaziu riservatu di u situ, pudete puru attivà diversi tippi di fori :', # MODIF
	'info_config_forums_prive_admin' => 'Un foru riservatu à l’amministratori di u situ :',
	'info_config_forums_prive_global' => 'Un foru generale, apertu à tutti i scrittori :',
	'info_config_forums_prive_objets' => 'Un foru per ogni artìculu, dispacciu, situ riferitu, etc. :',
	'info_desactiver_forum_public' => 'Disattivà l’adopru di i fori pùbblichi.
	I fori pùbblichi puderanu esse auturizati di volta in volta
	per i sìnguli artìculi; Invece seranu interdetti per e rùbbriche, i dispacci, etc.',
	'info_envoi_forum' => 'Nutìfiche da i fori à l’autori di l’artìculi',
	'info_fonctionnement_forum' => 'Funziunamentu di u foru :',
	'info_gauche_suivi_forum_2' => 'A pàgina di <i>guardia di i fori</i> hè un arnese di gestione di u situ (è micca un spaziu di ragiunata o di scrittura). 
		Nentru ci venenu pubblicati tutti i cuntributi di i fori di u situ, ch’elli sianu quelli di u situ pùbblicu o quelli di u spaziu privatu, 
		è vi permette a gestione di sti cuntributi.', # MODIF
	'info_liens_syndiques_3' => 'fori',
	'info_liens_syndiques_4' => 'stanu',
	'info_liens_syndiques_5' => 'foru',
	'info_liens_syndiques_6' => 'stà',
	'info_liens_syndiques_7' => 'in attesa di cunvalidazione',
	'info_mode_fonctionnement_defaut_forum_public' => 'Modu di funziunamentu predefinitu di i fori pùbblichi',
	'info_option_email' => 'Quando un visitore di u situ posta un novu messagiu in u foru
	assuciatu à un artìculu, l’autori di st’artìculu ne ponu esse
	avvisati da un email. Signalate puru per ogni tippu di foru s’ellu ci vole à usà st’opzione.',
	'info_pas_de_forum' => 'Nisunu foru',
	'info_question_visiteur_ajout_document_forum' => 'Sè vo vulete auturizà i visitori à alleà ducumenti (imàgini, mùsiche ...) à i so messagi di u foru, rinsignate quì sottu a lista di ’estensioni di i ducumenti auturizati pè i fori (per esempiu : gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Sè vo vulete auturizà tutti i tippi di ducumenti cunsiderati da affidati da SPIP, mettite una 
		stelluccia. Per ùn auturizà nunda, ùn mettite nunda.', # MODIF
	'item_activer_forum_administrateur' => 'Attivà u foru di l’amministratori',
	'item_config_forums_prive_global' => 'Attivà i fori di i scrittori',
	'item_config_forums_prive_objets' => 'Attivà sti fori',
	'item_desactiver_forum_administrateur' => 'Disattivà u foru di l’amministratori',
	'item_non_config_forums_prive_global' => 'Disattivà i fori di i scrittori',
	'item_non_config_forums_prive_objets' => 'Disattivà sti fori',

	// L
	'lien_reponse_article' => 'Risposta à l’artìculu',
	'lien_reponse_breve_2' => 'Risposta i dispacci',
	'lien_reponse_rubrique' => 'Risposta à a rùbbrica',
	'lien_reponse_site_reference' => 'Risposta à u situ riferitu :', # MODIF

	// O
	'onglet_messages_internes' => 'Messagi interni',
	'onglet_messages_publics' => 'Messagi pùbblichi',
	'onglet_messages_vide' => 'Messagi senza testu',

	// R
	'repondre_message' => 'Risponde à stu messagiu',

	// S
	'statut_original' => 'uriginale',

	// T
	'text_article_propose_publication_forum' => 'Date puru u vostru parè in u foru di st’artìculu (in fondu di pàgina).',
	'texte_en_cours_validation_forum' => 'Date puru u vostru parè usendu i fori chì li sò assuciati.',
	'titre_cadre_forum_administrateur' => 'Foru privatu di l’amministratori',
	'titre_cadre_forum_interne' => 'Foru internu',
	'titre_config_forums_prive' => 'Fori di u spaziu privatu',
	'titre_forum' => 'Foru',
	'titre_forum_suivi' => 'Guardia di i fori',
	'titre_page_forum_suivi' => 'Guardia di i fori'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_co.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=co
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'solu à l’artìculi futuri (nisuna mudìfica à a basa attuale).',
	'bouton_radio_articles_tous' => 'à tutti l’artìculi quant’elli sò.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'à tutti l’artìculi salvu quelli per chì hè disattivatu u foru.',
	'bouton_radio_enregistrement_obligatoire' => 'Arregistramenu ubbligatoriu (l’utilizatori devenu abbunà si rinsignendu u so indirizzu e-mail prima di pudè mandà cuntributi).',
	'bouton_radio_moderation_priori' => 'Muderazione in antìcipu (i cuntributi ùn sò pubblicati chè dopu accunsentu da l’amministratori).', # MODIF
	'bouton_radio_modere_abonnement' => 'Solu cù abbunamentu',
	'bouton_radio_modere_posteriori' => 'Muderazione dopu', # MODIF
	'bouton_radio_modere_priori' => 'muderazione in antìcipu', # MODIF
	'bouton_radio_publication_immediate' => 'Pubblicazione à l’istante di i messagi
(e cuntribuzioni sò pubblicate subbitu dopu mandate, l’amministradori i ponu sguassà dopu).',

	// D
	'documents_interdits_forum' => 'Ducumenti interdetti in u foru',

	// F
	'form_pet_message_commentaire' => 'Qualchì messagiu o cummentu ?',
	'forum' => 'Foru',
	'forum_acces_refuse' => 'Ùn avete più accessu à sti fori.',
	'forum_attention_dix_caracteres' => '<b>Attenti !</b> U vostru messagiu deve cuntene à u mìnimu dece caràtteri.',
	'forum_attention_trois_caracteres' => '<b>Attenti !</b> U vostru tìtulu deve cuntene à u mìnimu trè caràtteri.',
	'forum_attention_trop_caracteres' => '<b>Attention !</b> U vostru messagiu hè troppu longu (@compte@ caràtteri) : pè pudè esse arregistratu, 
	ùn deve superà @max@ caràtteri.', # MODIF
	'forum_avez_selectionne' => 'Avete sceltu :',
	'forum_cliquer_retour' => 'Cliccate <a href=\'@retour_forum@\'>quì</a> per cuntinuà.',
	'forum_forum' => 'foru',
	'forum_info_modere' => 'Stu foru hè muderatu prima : u vostru cuntributu cumpariscerà solu dopu esse statu accunsentutu da un amministratore di u situ.', # MODIF
	'forum_lien_hyper' => '<b>Lea ipertestu</b> (micca ubbligatoria)', # MODIF
	'forum_message_definitif' => 'Messagiu definitivu : mandà à u situ',
	'forum_message_trop_long' => 'U vostru messagiu hè troppu longu. A taglia màsima hè di 20 000 caràtteri.', # MODIF
	'forum_ne_repondez_pas' => 'Ùn rispundite micca à stu mail ma piuttostu nant’à u foru, à st’indirizzu :', # MODIF
	'forum_page_url' => '(Sì u vostru messagiu siriferisce à un artìculu pubblicatu nant’à u web, o à una pàgina 
	chì furnisce di più infurmazioni, pudete puru rinsignà custì u tìtulu di a pàgina cù u so indirizzu.)',
	'forum_poste_par' => 'Messagiu postu@parauteur@ in coda di l’artìculu « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Quale site ?</b> (micca ubbligatoriu)', # MODIF
	'forum_texte' => 'Testu di u vostru messagiu :', # MODIF
	'forum_titre' => 'Tìtulu',
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Cunvalidà sta scelta',
	'forum_voir_avant' => 'Vede u messagiu prima di pustà lu', # MODIF
	'forum_votre_email' => 'U vostru indirizzu email :', # MODIF
	'forum_votre_nom' => 'U vostru nome (o pseudo) :', # MODIF
	'forum_vous_enregistrer' => 'Per participà à stu foru, duvite esse digià arregistratu. 
		Rinsignate puru quì sottu u còdice persunale chì v’hè statu furnitu.
		Sè vo ùn site ancu à arregistrà, vi tocca à',
	'forum_vous_inscrire' => 'iscrive vi.',

	// I
	'icone_poster_message' => 'Mandà un messagiu',
	'icone_suivi_forum' => 'Guardia di u foru pùbblicu : @nb_forums@ cuntributi',
	'icone_suivi_forums' => 'Seguità/gestisce i fori',
	'icone_supprimer_message' => 'Sguassà stu messagiu',
	'icone_valider_message' => 'Cunvalidà stu messagiu',
	'info_activer_forum_public' => '<i>Per attivà i fori pùbblichi, sceglite puru u tippu 
	di muderazione predefinitu :</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Serà appiecata sta scelta di muderazione :',
	'info_config_forums_prive' => 'In u spaziu riservatu di u situ, pudete puru attivà diversi tippi di fori :', # MODIF
	'info_config_forums_prive_admin' => 'Un foru riservatu à l’amministratori di u situ :',
	'info_config_forums_prive_global' => 'Un foru generale, apertu à tutti i scrittori :',
	'info_config_forums_prive_objets' => 'Un foru per ogni artìculu, dispacciu, situ riferitu, etc. :',
	'info_desactiver_forum_public' => 'Disattivà l’adopru di i fori pùbblichi.
	I fori pùbblichi puderanu esse auturizati di volta in volta
	per i sìnguli artìculi; Invece seranu interdetti per e rùbbriche, i dispacci, etc.',
	'info_envoi_forum' => 'Nutìfiche da i fori à l’autori di l’artìculi',
	'info_fonctionnement_forum' => 'Funziunamentu di u foru :',
	'info_gauche_suivi_forum_2' => 'A pàgina di <i>guardia di i fori</i> hè un arnese di gestione di u situ (è micca un spaziu di ragiunata o di scrittura). 
		Nentru ci venenu pubblicati tutti i cuntributi di i fori di u situ, ch’elli sianu quelli di u situ pùbblicu o quelli di u spaziu privatu, 
		è vi permette a gestione di sti cuntributi.', # MODIF
	'info_liens_syndiques_3' => 'fori',
	'info_liens_syndiques_4' => 'stanu',
	'info_liens_syndiques_5' => 'foru',
	'info_liens_syndiques_6' => 'stà',
	'info_liens_syndiques_7' => 'in attesa di cunvalidazione',
	'info_mode_fonctionnement_defaut_forum_public' => 'Modu di funziunamentu predefinitu di i fori pùbblichi',
	'info_option_email' => 'Quando un visitore di u situ posta un novu messagiu in u foru
	assuciatu à un artìculu, l’autori di st’artìculu ne ponu esse
	avvisati da un email. Signalate puru per ogni tippu di foru s’ellu ci vole à usà st’opzione.',
	'info_pas_de_forum' => 'Nisunu foru',
	'info_question_visiteur_ajout_document_forum' => 'Sè vo vulete auturizà i visitori à alleà ducumenti (imàgini, mùsiche ...) à i so messagi di u foru, rinsignate quì sottu a lista di ’estensioni di i ducumenti auturizati pè i fori (per esempiu : gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Sè vo vulete auturizà tutti i tippi di ducumenti cunsiderati da affidati da SPIP, mettite una 
		stelluccia. Per ùn auturizà nunda, ùn mettite nunda.', # MODIF
	'item_activer_forum_administrateur' => 'Attivà u foru di l’amministratori',
	'item_config_forums_prive_global' => 'Attivà i fori di i scrittori',
	'item_config_forums_prive_objets' => 'Attivà sti fori',
	'item_desactiver_forum_administrateur' => 'Disattivà u foru di l’amministratori',
	'item_non_config_forums_prive_global' => 'Disattivà i fori di i scrittori',
	'item_non_config_forums_prive_objets' => 'Disattivà sti fori',

	// L
	'lien_reponse_article' => 'Risposta à l’artìculu',
	'lien_reponse_breve_2' => 'Risposta i dispacci',
	'lien_reponse_rubrique' => 'Risposta à a rùbbrica',
	'lien_reponse_site_reference' => 'Risposta à u situ riferitu :', # MODIF

	// O
	'onglet_messages_internes' => 'Messagi interni',
	'onglet_messages_publics' => 'Messagi pùbblichi',
	'onglet_messages_vide' => 'Messagi senza testu',

	// R
	'repondre_message' => 'Risponde à stu messagiu',

	// S
	'statut_original' => 'uriginale',

	// T
	'text_article_propose_publication_forum' => 'Date puru u vostru parè in u foru di st’artìculu (in fondu di pàgina).',
	'texte_en_cours_validation_forum' => 'Date puru u vostru parè usendu i fori chì li sò assuciati.',
	'titre_cadre_forum_administrateur' => 'Foru privatu di l’amministratori',
	'titre_cadre_forum_interne' => 'Foru internu',
	'titre_config_forums_prive' => 'Fori di u spaziu privatu',
	'titre_forum' => 'Foru',
	'titre_forum_suivi' => 'Guardia di i fori',
	'titre_page_forum_suivi' => 'Guardia di i fori',
];
